@@ -16,9 +16,12 @@ class TestMinimal(unittest.TestCase):
         # Create a window
         window = yd.Window()
 
-        # Draw a circle
+        # Draw a circle and a rectangle
         window.fill((100, 100, 200))
-        window.circle(center=(200, 200), radius=100, color=(255, 0, 255))
+        window.circle(center=(200, 200), radius=100, color=(200, 0, 100))
+        window.rectangle(rect=(200, 200, 100, 100), width=3, color=(0, 200, 0))
+        window.text(text="Hello World", position=(200, 200), size=48)
+        window.text(text="Hello World1", position=(600, 200), size=48)
 
         # Tell the window to update
         window.update()
